@@ -26,8 +26,7 @@ async def coromask(coro, args, kwargs, fargs):
             result = fargs(_in, obtained)
             return result
     except Exception:
-        print(msg, coro, args, kwargs, fargs)
-        raise Exception
+        raise Exception(msg)
 
 
 def renew(task, coro, fargs, *args, **kwargs):
@@ -40,13 +39,10 @@ def renew(task, coro, fargs, *args, **kwargs):
     :param fargs: the function to process input/output
     :param args: the unpacked list of extra arguments
     """
-    try:
-        if task.exception():
+    if not task.cancelled():
+        exception =task.exception()
+        if exception:
             raise task.result()
-    except asyncio.CancelledError as ce:
-        print("Task cancelled",ce)
-        raise ce
-    else:
         try:
             result = task.result()
             result_args, result_kwargs = result
@@ -58,6 +54,13 @@ def renew(task, coro, fargs, *args, **kwargs):
             print("Resultado", result, task, coro, fargs)
             print("Excepcion en renew", e)
             raise e
+    else:
+        try:
+            loop = task.get_loop()
+            loop.stop()
+            return False
+        except Exception as e:
+            raise e
 
 
 def simple_fargs(_in, obtained):
